@@ -17,13 +17,15 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OSupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
+from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
+from ai.h2o.sparkling.ml.params.HasDeprecatedVariableImportancesOnMOJO import HasDeprecatedVariableImportancesOnMOJO
 
 
-class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO):
+class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJO, HasDeprecatedVariableImportancesOnMOJO):
 
     @staticmethod
     def createFromMojo(pathToMojo, settings=H2OMOJOSettings.default()):
@@ -32,6 +34,17 @@ class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2ODeepLearningMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2ODeepLearningMOJOModel(javaModel)
 
+
+    def getCrossValidationModels(self):
+        cvModels = self._java_obj.getCrossValidationModelsAsArray()
+        if cvModels is None:
+            return None
+        elif isinstance(cvModels, JavaObject):
+            return [H2ODeepLearningMOJOModel(v) for v in cvModels]
+        else:
+            raise TypeError("Invalid type.")
+
+
     def getBalanceClasses(self):
         value = self._java_obj.getBalanceClasses()
         return value
@@ -232,8 +245,8 @@ class H2ODeepLearningMOJOModel(H2OSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         return value
 
 
-    def getVariableImportances(self):
-        value = self._java_obj.getVariableImportances()
+    def getCalculateFeatureImportances(self):
+        value = self._java_obj.getCalculateFeatureImportances()
         return value
 
 
